#  基础模板
-----------------------------

## 目录结构

- [工程目录](#工程目录)
- [页面配置](#页面配置)
- [如何引用第三方框架](#如何引用第三方框架)

## 工程目录

```text
  |—— build
  │   ├── common // jsapi文件目录
  │   └── apps   // 打包生成的app目录
  |—— public // 公用文件。不经过webpack处理，需要在html引用
  |—— server.config.js // 开发环境设置，可修项目名称、端口号等
  ├── src // 源代码目录
  │   ├── desc // desc文件
  │   ├── html // html文件
  │   ├── app.js // 公用js
  │   ├── app.css // 公用样式
  │   └── app.json // 路由配置文件
  ├── .eslintrc // eslint配置文件  
  ├── package.json // 包含 npm 依赖包
  ├── plugin.json // 配置文件
  └── webpack.config.js // webpack配置文件
```

## 页面配置

在项目 src 目录 app.json 中，添加配置，如：

```json
{
    "pages": [
        "html/index",
        "desc/index"
    ]
}
```

以新增 `html/index.html` 页面为例：

1. 新增两个文件 `html/index.html` 和 `html/index.js`。
2. 添加配置，将 `html/index` 到 `app.json` 的 `pages` 字段中。

注意，`index`.html 和 `index`.js 两文件需和配置 `html/index` 的 `index` 命名需保持一致。

## 如何引用第三方框架

如何引用第三方框架，如 zepto，vue 等...

示例：

global引入：将压缩过的 `zepto.min.js` 放在 `public/js` 文件夹中。

在 html/index.html 中引用：

```html
<script src="../js/zepto.min.js"></script>
```

在 js 中引用，如 `html/index.js`：

```js
Zepto(() => {
  console.log('Ready to Zepto!');
});
```

> 注意：在启动过程才会复制 public 里面的文件到项目根目录中，所以需要重启才能生效。